grib2io.tables.section5 API documentation

# grib2io.tables.section5

View Source

     1table_5_0 = {
     2'0':'Grid Point Data - Simple Packing (see Template 5.0)',
     3'1':'Matrix Value at Grid Point - Simple Packing (see Template 5.1)',
     4'2':'Grid Point Data - Complex Packing (see Template 5.2)',
     5'3':'Grid Point Data - Complex Packing and Spatial Differencing (see Template 5.3)',
     6'4':'Grid Point Data - IEEE Floating Point Data (see Template 5.4)',
     7'5-39':'Reserved',
     8'40':'Grid point data - JPEG 2000 code stream format (see Template 5.40)',
     9'41':'Grid point data - Portable Network Graphics (PNG) (see Template 5.41)',
    10'42':'Grid point data - CCSDS recommended lossless compression (see Template 5.42)',
    11'43-49':'Reserved',
    12'50':'Spectral Data - Simple Packing (see Template 5.50)',
    13'51':'Spectral Data - Complex Packing (see Template 5.51)',
    14'52':'Reserved',
    15'53':'Spectral data for limited area models - complex packing (see Template 5.53)',
    16'54-60':'Reserved',
    17'61':'Grid Point Data - Simple Packing With Logarithm Pre-processing (see Template 5.61)',
    18'62-199':'Reserved',
    19'200':'Run Length Packing With Level Values (see Template 5.200)',
    20'201-49151':'Reserved',
    21'49152-65534':'Reserved for Local Use',
    22'65535':'Missing',
    23}
    24
    25table_5_1 = {
    26'0':'Floating Point',
    27'1':'Integer',
    28'2-191':'Reserved',
    29'192-254':'Reserved for Local Use',
    30'255':'Missing',
    31}
    32
    33table_5_2 = {
    34'0':'Explicit Coordinate Values Set',
    35'1':'Linear Coordinates f(1) = C1 f(n) = f(n-1) + C2',
    36'2-10':'Reserved',
    37'11':'Geometric Coordinates f(1) = C1 f(n) = C2 x f(n-1)',
    38'12-191':'Reserved',
    39'192-254':'Reserved for Local Use',
    40'255':'Missing',
    41}
    42
    43table_5_3 = {
    44'0':'Reserved',
    45'1':'Direction Degrees True',
    46'2':'Frequency (s-1)',
    47'3':'Radial Number (2pi/lamda) (m-1)',
    48'4-191':'Reserved',
    49'192-254':'Reserved for Local Use',
    50'255':'Missing',
    51}
    52
    53table_5_4 = {
    54'0':'Row by Row Splitting',
    55'1':'General Group Splitting',
    56'2-191':'Reserved',
    57'192-254':'Reserved for Local Use',
    58'255':'Missing',
    59}
    60
    61table_5_5 = {
    62'0':'No explicit missing values included within the data values',
    63'1':'Primary missing values included within the data values',
    64'2':'Primary and secondary missing values included within the data values',
    65'3-191':'Reserved',
    66'192-254':'Reserved for Local Use',
    67}
    68
    69table_5_6 = {
    70'0':'Reserved',
    71'1':'First-Order Spatial Differencing',
    72'2':'Second-Order Spatial Differencing',
    73'3-191':'Reserved',
    74'192-254':'Reserved for Local Use',
    75'255':'Missing',
    76}
    77
    78table_5_7 = {
    79'0':'Reserved',
    80'1':'IEEE 32-bit (I=4 in Section 7)',
    81'2':'IEEE 64-bit (I=8 in Section 7)',
    82'3':'IEEE 128-bit (I=16 in Section 7)',
    83'4-254':'Reserved',
    84'255':'Missing',
    85}
    86
    87table_5_40 = {
    88'0':'Lossless',
    89'1':'Lossy',
    90'2-254':'Reserved',
    91'255':'Missing',
    92}